import BaseExtension from './base-extension';
import Scope from '../scope/scope';
import { EnvType, EnvLoadArgsProps, EnvExtensionProps, EnvExtensionModel, EnvExtensionSerializedModel } from './env-extension-types';
import ExtensionFile from './extension-file';
import { Repository } from '../scope/objects';
import { PathOsBased } from '../utils/path';
import { EnvExtensionObject } from '../consumer/config/abstract-config';
import { ComponentWithDependencies } from '../scope';
import { ComponentOrigin } from '../consumer/bit-map/component-map';
import ConsumerComponent from '../consumer/component';
import WorkspaceConfig from '../consumer/config/workspace-config';
import ComponentConfig from '../consumer/config';
import { Dependencies } from '../consumer/component/dependencies';
import ConfigDir from '../consumer/bit-map/config-dir';
import DataToPersist from '../consumer/component/sources/data-to-persist';
import Consumer from '../consumer/consumer';
import { ConsumerOverridesOfComponent } from '../consumer/config/consumer-overrides';
export declare type EnvPackages = {
    dependencies?: Record<string, any>;
    devDependencies?: Record<string, any>;
    peerDependencies?: Record<string, any>;
};
export default class EnvExtension extends BaseExtension {
    envType: EnvType;
    dynamicPackageDependencies: Record<string, any> | null | undefined;
    files: ExtensionFile[];
    dataToPersist: DataToPersist;
    get action(): Function | null | undefined;
    get oldAction(): Function | null | undefined;
    constructor(extensionProps: EnvExtensionProps);
    install(scope: Scope, opts: {
        verbose: boolean;
        dontPrintEnvMsg?: boolean;
    }, context?: Record<string, any>): Promise<ComponentWithDependencies[] | null | undefined>;
    toModelObject(): EnvExtensionModel;
    toObject(): Record<string, any>;
    toBitJsonObject(ejectedEnvDirectory: string): {
        [key: string]: EnvExtensionObject;
    };
    populateDataToPersist({ configDir, envType, deleteOldFiles, consumer, verbose }: {
        configDir: string;
        envType: EnvType;
        deleteOldFiles: boolean;
        consumer: Consumer | null | undefined;
        verbose: boolean;
    }): Promise<string>;
    removeFilesFromFs(dependencies: Dependencies, configDir: ConfigDir, envType: EnvType, consumerPath: PathOsBased): Promise<boolean>;
    reload(scopePath: string, context?: Record<string, any>): Promise<void>;
    static load(props: EnvLoadArgsProps): Promise<EnvExtensionProps>;
    static loadDynamicPackageDependencies(envExtensionProps: EnvExtensionProps): EnvPackages | null | undefined;
    static loadDynamicConfig(envExtensionProps: EnvExtensionProps): Record<string, any> | null | undefined;
    static loadFromModelObject(modelObject: EnvExtensionModel & {
        envType: EnvType;
    }, repository: Repository): Promise<EnvExtensionProps>;
    static loadFromSerializedModelObject(modelObject: EnvExtensionSerializedModel & {
        envType: EnvType;
    }): Promise<EnvExtensionProps>;
    static loadFromCorrectSource({ consumerPath, scopePath, componentOrigin, componentFromModel, componentConfig, overridesFromConsumer, workspaceConfig, envType, context }: {
        consumerPath: string;
        scopePath: string;
        componentOrigin: ComponentOrigin;
        componentFromModel: ConsumerComponent;
        componentConfig: ComponentConfig | null | undefined;
        overridesFromConsumer: ConsumerOverridesOfComponent | null | undefined;
        workspaceConfig: WorkspaceConfig;
        envType: EnvType;
        context?: Record<string, any>;
    }): Promise<EnvExtension | null | undefined>;
    static areEnvsDifferent(envModelA: EnvExtensionModel | null | undefined, envModelB: EnvExtensionModel | null | undefined): boolean;
}
