/// <reference types="node" />
import { Ref, BitObject } from '../objects';
import Source from './source';
import { customResolvedPath, ExtensionData } from '../../consumer/component/consumer-component';
import ConsumerComponent from '../../consumer/component';
import { BitIds, BitId } from '../../bit-id';
import { Doclet } from '../../jsdoc/types';
import { Results } from '../../consumer/specs-results/specs-results';
import { Dependencies, Dependency } from '../../consumer/component/dependencies';
import { PathLinux, PathLinuxRelative } from '../../utils/path';
import { CompilerExtensionModel } from '../../extensions/compiler-extension';
import { TesterExtensionModel } from '../../extensions/tester-extension';
import { SourceFile } from '../../consumer/component/sources';
import Repository from '../objects/repository';
import { ComponentOverridesData } from '../../consumer/config/component-overrides';
import { EnvPackages } from '../../extensions/env-extension';
declare type CiProps = {
    error: Record<string, any>;
    startTime: string;
    endTime: string;
};
export declare type SourceFileModel = {
    name: string;
    relativePath: PathLinux;
    test: boolean;
    file: Ref;
};
export declare type DistFileModel = SourceFileModel;
export declare type Log = {
    message: string;
    date: string;
    username: string | null | undefined;
    email: string | null | undefined;
};
export declare type VersionProps = {
    mainFile: PathLinux;
    files: Array<SourceFileModel>;
    dists?: Array<DistFileModel> | null | undefined;
    mainDistFile: PathLinux | null | undefined;
    compiler?: CompilerExtensionModel | null | undefined;
    tester?: TesterExtensionModel | null | undefined;
    log: Log;
    ci?: CiProps;
    specsResults?: Results | null | undefined;
    docs?: Doclet[];
    dependencies?: Dependency[];
    devDependencies?: Dependency[];
    compilerDependencies?: Dependency[];
    testerDependencies?: Dependency[];
    flattenedDependencies?: BitIds;
    flattenedDevDependencies?: BitIds;
    flattenedCompilerDependencies?: BitIds;
    flattenedTesterDependencies?: BitIds;
    packageDependencies?: {
        [key: string]: string;
    };
    devPackageDependencies?: {
        [key: string]: string;
    };
    peerPackageDependencies?: {
        [key: string]: string;
    };
    compilerPackageDependencies?: EnvPackages;
    testerPackageDependencies?: EnvPackages;
    bindingPrefix?: string;
    customResolvedPaths?: customResolvedPath[];
    overrides: ComponentOverridesData;
    packageJsonChangedProps?: Record<string, any>;
    extensions?: ExtensionData[];
};
export default class Version extends BitObject {
    mainFile: PathLinux;
    files: Array<SourceFileModel>;
    dists: Array<DistFileModel> | null | undefined;
    mainDistFile: PathLinuxRelative | null | undefined;
    compiler: CompilerExtensionModel | null | undefined;
    tester: TesterExtensionModel | null | undefined;
    log: Log;
    ci: CiProps | {};
    specsResults: Results | null | undefined;
    docs: Doclet[] | null | undefined;
    dependencies: Dependencies;
    devDependencies: Dependencies;
    compilerDependencies: Dependencies;
    testerDependencies: Dependencies;
    flattenedDependencies: BitIds;
    flattenedDevDependencies: BitIds;
    flattenedCompilerDependencies: BitIds;
    flattenedTesterDependencies: BitIds;
    packageDependencies: {
        [key: string]: string;
    };
    devPackageDependencies: {
        [key: string]: string;
    };
    peerPackageDependencies: {
        [key: string]: string;
    };
    compilerPackageDependencies: EnvPackages;
    testerPackageDependencies: EnvPackages;
    bindingPrefix: string | null | undefined;
    customResolvedPaths: customResolvedPath[] | null | undefined;
    overrides: ComponentOverridesData;
    packageJsonChangedProps: Record<string, any>;
    extensions: ExtensionData[];
    constructor(props: VersionProps);
    validateVersion(): void;
    id(): string;
    getAllFlattenedDependencies(): BitIds;
    getAllDependencies(): Dependency[];
    getAllDependenciesCloned(): Dependencies;
    getAllDependenciesIds(): BitIds;
    updateFlattenedDependency(currentId: BitId, newId: BitId): void;
    refs(): Ref[];
    toObject(): any;
    validateBeforePersisting(versionStr: string): void;
    toBuffer(pretty: boolean): Buffer;
    static parse(contents: string): Version;
    static from(versionProps: VersionProps): Version;
    static fromComponent({ component, files, dists, mainDistFile, flattenedDependencies, flattenedDevDependencies, flattenedCompilerDependencies, flattenedTesterDependencies, message, specsResults, username, email }: {
        component: ConsumerComponent;
        files: Array<SourceFileModel>;
        flattenedDependencies: BitIds;
        flattenedDevDependencies: BitIds;
        flattenedCompilerDependencies: BitIds;
        flattenedTesterDependencies: BitIds;
        message: string;
        dists: Array<DistFileModel> | null | undefined;
        mainDistFile: PathLinuxRelative;
        specsResults: Results | null | undefined;
        username: string | null | undefined;
        email: string | null | undefined;
    }): any;
    setSpecsResults(specsResults: Results | null | undefined): void;
    setDist(dist: Source | null | undefined): void;
    setCIProps(ci: CiProps): void;
    modelFilesToSourceFiles(repository: Repository): Promise<SourceFile[]>;
    validate(): void;
}
export {};
